==> MassWateR_2.0.2.tar.gz: MassWateR/R/globalVariables.R <==
globalVariables(c("Activity Start Date", "Activity Start Time", "QC Reference Value", "Result Unit",
                  "Parameter", "...7", "MDL", "UQL", "uom", "Monitoring Location Latitude", 
                  "Monitoring Location Longitude", "Characteristic Name", "obs", "percent", 
                  "% Completeness", "met", "name", "value", "paramsMWR", "Simple Parameter", 
                  "Units of measure", "Units of measure.x", "Units of measure.y", 
                  "WQX Parameter", "datarec", "qualrec", "standard", "Activity Type", 
                  "check", "Type", "Frequency %", ".", "Monitoring Location ID", "Result Value", 
                  "Result", "MDL Unit", "Field Blank", "Lab Blank", "Spike/Check Accuracy", 
                  "Date", "Diff./RPD", "Dup. Result", "Dup. Result2", "Field Duplicate",
                  "Hit/Miss", "Initial Result", "Initial Result2", "Lab Duplicate", "Recovered",
                  "Recovered2", "Reference", "Site", "Standard", "Standard2", "Value Range", 
                  "diffv", "flt", "percv", "Avg. Result", "Sample ID", "ind", "Result Attribute", 
                  "rngflt", "recov", "% Acceptance", "Number of Misses", "Number of QC Checks", 
                  "isnum", "Quantitation Limit", "Threshold", "Month", "outlier", "Week", "grpvar", 
                  "hiv", "label", "lov", "meanval","num", "thresholdMWR", "degree", "geometry", 
                  "Location Group", "sitdat", "pondsMWR", "riversMWR", "streamsMWR", 
                  "Activity Depth/Height Measure", "kilometer", "Activity Relative Depth Name", 
                  "Diff./Accuracy", "signv", "x", "y", "Activity Depth/Height Unit", 
                  "Activity ID", "Activity Media Name", "Activity Start Time Zone",
                  "Characteristic Name User Supplied", "Method Speciation", 
                  "Monitoring Location Horizontal Collection Method", 
                  "Monitoring Location Horizontal Coordinate Reference System",
                  "Monitoring Location Latitude (DD.DDDD)", 
                  "Monitoring Location Longitude (-DDD.DDDD)", "Monitoring Location Name",
                  "Monitoring Location Source Map Scale (conditional)", "Monitoring Location Type",
                  "Project ID", "Result Analytical Method Context", "Result Analytical Method ID",
                  "Result Comment", "Result Detection Condition", 
                  "Result Detection/Quantitation Limit Measure", 
                  "Result Detection/Quantitation Limit Type", 
                  "Result Detection/Quantitation Limit Unit", "Result Measure Qualifier",
                  "Result Sample Fraction", "Result Status ID", "Result Value Type", 
                  "Result Value2", "Sample Collection Equipment Name", 
                  "Sample Collection Method Context", "Sample Collection Method ID", 
                  "Tribal Land Indicator (Yes/No) (optional)", "Tribal Land Name (optional)",
                  "actstrtm", "actyaid", "dateaid", "deptaid", "moniaid", "timeaid", "dLevel",
                  "Analytical Method", "Analytical Method Context", "Field Blankna", 
                  "Field Duplicate2", "Field Duplicatena", "Lab Blankna", "Lab Duplicate2",
                  "Lab Duplicatena", "Sampling Method Context", "Spike/Check Accuracy2", 
                  "Spike/Check Accuracyna", "Result Detection/Quantitation Limit Value"
                  ))

#' @importFrom stats IQR na.omit quantile t.test
NULL

#' @importFrom grDevices dev.off png
NULL 

#' @importFrom utils write.csv
NULL

==> MassWateR_2.1.0.tar.gz: MassWateR/R/globalVariables.R <==
globalVariables(c("Activity Start Date", "Activity Start Time", "QC Reference Value", "Result Unit",
                  "Parameter", "...7", "MDL", "UQL", "uom", "Monitoring Location Latitude", 
                  "Monitoring Location Longitude", "Characteristic Name", "obs", "percent", 
                  "% Completeness", "met", "name", "value", "paramsMWR", "Simple Parameter", 
                  "Units of measure", "Units of measure.x", "Units of measure.y", 
                  "WQX Parameter", "datarec", "qualrec", "standard", "Activity Type", 
                  "check", "Type", "Frequency %", ".", "Monitoring Location ID", "Result Value", 
                  "Result", "MDL Unit", "Field Blank", "Lab Blank", "Spike/Check Accuracy", 
                  "Date", "Diff./RPD", "Dup. Result", "Dup. Result2", "Field Duplicate",
                  "Hit/Miss", "Initial Result", "Initial Result2", "Lab Duplicate", "Recovered",
                  "Recovered2", "Reference", "Site", "Standard", "Standard2", "Value Range", 
                  "diffv", "flt", "percv", "Avg. Result", "Sample ID", "ind", "Result Attribute", 
                  "rngflt", "recov", "% Acceptance", "Number of Misses", "Number of QC Checks", 
                  "isnum", "Quantitation Limit", "Threshold", "Month", "outlier", "Week", "grpvar", 
                  "hiv", "label", "lov", "meanval","num", "thresholdMWR", "degree", "geometry", 
                  "Location Group", "sitdat", "pondsMWR", "riversMWR", "streamsMWR", 
                  "Activity Depth/Height Measure", "kilometer", "Activity Relative Depth Name", 
                  "Diff./Accuracy", "signv", "x", "y", "Activity Depth/Height Unit", 
                  "Activity ID", "Activity Media Name", "Activity Start Time Zone",
                  "Characteristic Name User Supplied", "Method Speciation", 
                  "Monitoring Location Horizontal Collection Method", 
                  "Monitoring Location Horizontal Coordinate Reference System",
                  "Monitoring Location Latitude (DD.DDDD)", 
                  "Monitoring Location Longitude (-DDD.DDDD)", "Monitoring Location Name",
                  "Monitoring Location Source Map Scale (conditional)", "Monitoring Location Type",
                  "Project ID", "Result Analytical Method Context", "Result Analytical Method ID",
                  "Result Comment", "Result Detection Condition", 
                  "Result Detection/Quantitation Limit Measure", 
                  "Result Detection/Quantitation Limit Type", 
                  "Result Detection/Quantitation Limit Unit", "Result Measure Qualifier",
                  "Result Sample Fraction", "Result Status ID", "Result Value Type", 
                  "Result Value2", "Sample Collection Equipment Name", 
                  "Sample Collection Method Context", "Sample Collection Method ID", 
                  "Tribal Land Indicator (Yes/No) (optional)", "Tribal Land Name (optional)",
                  "actstrtm", "actyaid", "dateaid", "deptaid", "moniaid", "timeaid", "dLevel",
                  "Analytical Method", "Analytical Method Context", "Field Blankna", 
                  "Field Duplicate2", "Field Duplicatena", "Lab Blankna", "Lab Duplicate2",
                  "Lab Duplicatena", "Sampling Method Context", "Spike/Check Accuracy2", 
                  "Spike/Check Accuracyna", "Result Detection/Quantitation Limit Value",
                  "Local Record ID", "Activity ID User Supplied"
                  ))

#' @importFrom stats IQR na.omit quantile t.test
NULL

#' @importFrom grDevices dev.off png
NULL 

#' @importFrom utils write.csv
NULL 

#' @importFrom tools file_path_sans_ext
NULL
